==> peperit_2.0_estable.zip: themes/peperit/html_files/componentes/escaparates/EscaparteDesplegable/lineaEscaparate.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 26/Abril/2017
// Versión 1.0 Fichero que muestra los li de la lista de escaparates
//---------------------------------------------------------------------------------------------------------
/*
  Variables disponibles:
  $escaparateActual
  $nivel_maximo
  $condicion
  $activo
  $limite
  $nivel
 */

$columnas = 'col-md-4';

if ($nivel == 0) {
    ?>
    {hijos}
    <?php
} else if ($nivel == 1) {
    $hasChildren = '';
    if (count($escaparateActual->hijos) > 0) {
        $hasChildren = 'hasChildren';
    }
    ?>
    <li class="nivel_<?= $nivel; ?> v-megamenuitem <?= $hasChildren; ?>">
        <a class="menu-title" href="<?= $escaparateActual->url; ?>"><span class="item-icon"><?= $escaparateActual->nombre_natural; ?></span></a>
        <?php
        if (count($escaparateActual->hijos) > 0) {
            ?>
            <a href="javascript:void(0);" class="opener"></a>
            <?php
        }
        ?>
        {hijos}
    </li>
    <?php
} else if ($nivel == 2) {
    ?>
    <li class="<?= $columnas; ?> columna">
        <a class="menu-item-title" href="<?= $escaparateActual->url; ?>"><?= $escaparateActual->nombre_natural; ?></a>
        <?php
        if (count($escaparateActual->hijos) > 0) {
            ?>
            <a href="javascript:void(0);" class="opener"></a>
            <?php
        }
        ?>
        {hijos}
    </li>
    <?php
} else if ($nivel == 3) {
    ?>
    <li class = "<?= $columnas; ?>columnaN3"><a class = "menu-item-title" href = "<?= $escaparateActual->url; ?>"><?= $escaparateActual->nombre_natural; ?></a></li>
    <?php
}
?>

==> peperit_2.1.01_estable.zip: themes/peperit/html_files/componentes/escaparates/EscaparteDesplegable/lineaEscaparate.php <==
<?php
//---------------------------------------------------------------------------------------------------------
// 26/Abril/2017
// Versión 1.0 Fichero que muestra los li de la lista de escaparates
//---------------------------------------------------------------------------------------------------------
/*
  Variables disponibles:
  $escaparateActual
  $nivel_maximo
  $condicion
  $activo
  $limite
  $nivel
 */

$columnas = 'col-md-4';

if ($nivel == 0) {
    ?>
    {hijos}
    <?php
} else if ($nivel == 1) {
    $hasChildren = '';
    if (count($escaparateActual->hijos) > 0) {
        $hasChildren = 'hasChildren';
    }
    ?>
    <li class="nivel_<?= $nivel; ?> v-megamenuitem <?= $hasChildren; ?>">
        <a class="menu-title" href="<?= $escaparateActual->url; ?>"><span class="item-icon"><?= $escaparateActual->nombre_natural; ?></span></a>
        <?php
        if (count($escaparateActual->hijos) > 0) {
            ?>
        <span id="opener<?= $escaparateActual->codigo; ?>" class="opener collapsed" data-toggle="collapse" data-target="#esca<?= $escaparateActual->codigo; ?>" aria-expanded="false"></span>
            <?php
            /*            <a href="javascript:$('#esca<?= $escaparateActual->codigo; ?>').toggle('slow');" id="opener<?= $escaparateActual->codigo; ?>" class="opener"></a>  */
        }
        ?>
        
        {hijos}
    </li>
    <?php
} else if ($nivel == 2) {
    ?>
    <li class="<?= $columnas; ?> columna">
        <a class="menu-item-title" href="<?= $escaparateActual->url; ?>"><?= $escaparateActual->nombre_natural; ?></a>
        <?php
        if (count($escaparateActual->hijos) > 0) {
            ?>
            <a href="javascript:$('#esca<?= $escaparateActual->codigo; ?>').toggle('slow');" class="opener"></a>
            <?php
        }
        ?>
      
        {hijos}
    </li>
    <?php
} else if ($nivel == 3) {
    ?>
    <li class = "<?= $columnas; ?>columnaN3"><a class = "menu-item-title" href = "<?= $escaparateActual->url; ?>"><?= $escaparateActual->nombre_natural; ?></a></li>
    <?php
}
?>
